@@ -87,6 +87,7 @@ def generate_default_project_settings(
     default_config = [ 
 """
 model_name: my_model
+human_friendly_model_name: 'My model'
 model_file: model_code/my_model.py
 req_file: model_code/requirements.model
 test_file: model_code/test_model.py
@@ -124,6 +125,7 @@ def validate_model_reqs(req_file):
 @dataclass
 class ServiceSettings():
     model_name: str # Remember to modify generate_default_project_settings()
+    human_friendly_model_name: str
     model_file: FilePath # if fields are modified
     req_file: FilePath
     test_file: Optional[FilePath]
