@@ -38,11 +38,13 @@ def deploy_model(model_settings, platform_methods=platform_methods):
         service_name = config.envs.service_name
         deployment_folder = helpers.deployment_folder_path(c.model_name)
         function_name = f"{c.model_name}-{service_name}-{env}"
+        human_readable_function_name = c.human_friendly_model_name
 
         logging.debug(" ")
-        logging.info(f"Deploy model {c.model_name}")
+        logging.info(f"Starting deployment of model {c.human_friendly_model_name} with external id {function_name}")
 
         if (service_name == 'prediction') and c.artifact_folder:
+            mm.set_active_dataset(c.dataset)
             c.model_id = mm.set_up_model_artifact(c.artifact_folder, c.model_name)
 
         logging.info("Create deployment folder and move required files/folders")
@@ -65,9 +67,9 @@ def deploy_model(model_settings, platform_methods=platform_methods):
         else:
             logging.warning("Model test file is missing! Didn't run tests")
 
-        logging.info(f"Deploy {function_name} to {c.platform}")
+        logging.info(f"Deploying function {human_readable_function_name} with external id {function_name} to {c.platform}")
         deploy_function, test_function = platform_methods[c.platform]
-        deploy_function(function_name, info=c.info[service_name])
+        deploy_function(human_readable_function_name, function_name, info=c.info[service_name])
         
         if c.test_file:
             logging.info("Make a test call")
@@ -98,7 +100,7 @@ def deploy(project_settings):
         status = deploy_model(c)
         if status != "OK":
             logging.error(status)
-            failed_models[c.model_name] = status
+            failed_models[c.human_friendly_model_name] = status
         
         logging.debug(f"cd ..")
         os.chdir(cwd_path)
